Local

Struct Local 

pub struct Local<T> { /* private fields */ }
Durability implementation backed by a Commitlog on local storage.

The commitlog is constrained to store the canonical Txdata payload, where the generic parameter T is the type of the row data stored in the mutations section.

T is left generic in order to allow bypassing the ProductValue intermediate representation in the future.

Note, however, that instantiating T to a different type may require to change the log format version!

Implementations

Source

impl<T: Encode + Send + Sync + 'static> Local<T>

pub fn open(root: CommitLogDir, rt: Handle, opts: Options) -> Result<Self>

Create a Local instance at the root directory.

The root directory must already exist.

Background tasks are spawned onto the provided tokio runtime.

pub fn queue_depth(&self) -> u64

Inspect how many transactions added via Self::append_tx are pending to be applied to the underlying Commitlog.

pub fn commits_from( &self, offset: TxOffset, ) -> impl Iterator<Item = Result<Commit, Traversal>>

Obtain an iterator over the Commits in the underlying log.

pub fn existing_segment_offsets(&self) -> Result<Vec<TxOffset>>

Get a list of segment offsets, sorted in ascending order.

pub fn compress_segments(&self, offsets: &[TxOffset]) -> Result<()>

Compress the segments at the offsets provided, marking them as immutable.

pub async fn close(self) -> Result<Option<TxOffset>>

Apply all outstanding transactions to the Commitlog and flush it to disk.

Returns the durable TxOffset, if any.

pub fn size_on_disk(&self) -> Result<u64>

Get the size on disk of the underlying Commitlog.